
/*

  Read a state file in the form generated by the simulation program,
  and convert it to a new format (suitable for reading by FORTRAN
  programs).

*/

#include <stdio.h>
#include "datahdr.h"
#include "strmhdr.h"
#include "fstrmhdr.h"

static char *usage        = "USAGE: gconvert <infile> <outfile>\n" ;

extern void sums () ;

void get_params (file1, file2, argc, argv)
char **file1, **file2 ;
int argc ;
char *argv [] ;
{
  if (argc != 3)
  {
    fprintf (stderr, usage) ;
    exit (1) ;
  }

  if (! strcmp (argv [1], "-"))
    *file1 = NULL ;
  else
    *file1 = argv [1] ;

  if (! strcmp (argv [2], "-"))
    *file2 = NULL ;
  else
    *file2 = argv [2] ;
}

void main (argc, argv)
int argc ;
char *argv [] ;
{
  char *file1, *file2 ;
  DATA  *data1 ;
  FDATA *data2 ;
  int   params [NUM_STT_PARAMS + NUM_DAT_PARAMS] ;
  float coeffs [NUM_STT_COEFFS + NUM_DAT_COEFFS] ;
  int l_time, l_space, n_repl ;

  get_params  (&file1, &file2, argc, argv) ;

  data1 = data_open_read (file1) ;
  read_header (data1) ;
  read_coeffs (data1, coeffs) ;
  read_params (data1, params) ;

  data2 = fdata_open_write (file2) ;
  fdata_write_header (data2, NUM_STT_PARAMS, params,
                             NUM_STT_COEFFS, coeffs) ;

  fprintf (stderr, "%d\n", params [STT_L_T   ]) ;
  fprintf (stderr, "%d\n", params [STT_L_X   ]) ;
  fprintf (stderr, "%d\n", params [STT_L_Y   ]) ;
  fprintf (stderr, "%d\n", params [STT_L_Z   ]) ;
  fprintf (stderr, "%d\n", params [STT_N_REPS]) ;
  fprintf (stderr, "\n") ;

  l_time  = params [STT_L_T] ;
  l_space = params [STT_L_X] * params [STT_L_Y] * params [STT_L_Z] ;
  n_repl  = params [STT_N_REPS] ;

  read_field_begin (data1) ;
  fdata_write_field_begin (data2) ;
  convert (data1, data2, l_time, l_space, n_repl) ;
  fdata_write_field_end   (data2) ;

  data_close  (data1) ;
  fdata_close (data2) ;
}

